@@ -7,7 +7,7 @@
 
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qhbox.h>
+#include <q3hbox.h>
 #include <qslider.h>
 #include <qlabel.h>
 #include <qlcdnumber.h>
@@ -19,6 +19,10 @@
 #include <qcheckbox.h>
 #include <qwidget.h>
 #include <qsound.h>
+//Added by qt3to4:
+#include <QKeyEvent>
+#include <QMouseEvent>
+#include <QPaintEvent>
 
 #include <cmath>
 #include <ctime>
@@ -84,7 +88,7 @@ QLiss3D::QLiss3D(QWidget *parent, const char *name) : QWidget(parent, name){
 	
 	setFixedSize(800,600);
 	srand(time((time_t *)NULL));
-	setFocusPolicy(QWidget::StrongFocus);
+	setFocusPolicy(Qt::StrongFocus);
 	setFocus();
 
 	randomFigure();
@@ -110,32 +114,37 @@ QLiss3D::QLiss3D(QWidget *parent, const char *name) : QWidget(parent, name){
 	connect(this,SIGNAL(zFreqChanged(int)),    SLOT(setDensity()));
 	really_repaint = 1;
 	repaintMe();
-	help = new QVBox;
-	QHBox *help2 = new QHBox(help);
-		QVBox *help3 = new QVBox(help2);
-			QLabel *l1  = new QLabel(tr("turn figure"),help3);
-			QLabel *l2  = new QLabel(tr("reset angle"),help3);
-			QLabel *l3  = new QLabel(tr("change red color value"),help3);
-			QLabel *l4  = new QLabel(tr("change green color value"),help3);
-			QLabel *l5  = new QLabel(tr("change blue color value"),help3);
-			QLabel *l6  = new QLabel(tr("zoom"),help3);
-			QLabel *l7  = new QLabel(tr("change density"),help3);
-			QLabel *l8  = new QLabel(tr("x phase shift"),help3);
-			QLabel *l9  = new QLabel(tr("y phase shift"),help3);
-			QLabel *l10 = new QLabel(tr("z phase shift"),help3);
-			QLabel *l11 = new QLabel(tr("toggle information"),help3);
-		QVBox *help4 = new QVBox(help2);
-			QLabel *c1  = new QLabel(tr("cursor keys, mouse dragging"),help4);
-			QLabel *c2  = new QLabel(tr("page up / page down"),help4);
-			QLabel *c3  = new QLabel(tr("r / t"),help4);
-			QLabel *c4  = new QLabel(tr("g / h"),help4);
-			QLabel *c5  = new QLabel(tr("b / n"),help4);
-			QLabel *c6  = new QLabel(tr("+ / -"),help4);
-			QLabel *c7  = new QLabel(tr("Ins / Del"),help4);
-			QLabel *c8  = new QLabel(tr("y / x"),help4);
-			QLabel *c9  = new QLabel(tr("a / s"),help4);
-			QLabel *c10 = new QLabel(tr("q / w"),help4);
-			QLabel *c11 = new QLabel(tr("i"),help4);
+	help = new Q3VBox;
+	Q3HBox *help2 = new Q3HBox(help);
+	Q3VBox *help3 = new Q3VBox(help2);
+	QLabel *l1  = new QLabel(tr("turn figure"),help3);
+	QLabel *l2  = new QLabel(tr("reset angle"),help3);
+	QLabel *l3  = new QLabel(tr("change red color value"),help3);
+	QLabel *l4  = new QLabel(tr("change green color value"),help3);
+	QLabel *l5  = new QLabel(tr("change blue color value"),help3);
+	QLabel *l6  = new QLabel(tr("zoom"),help3);
+	QLabel *l7  = new QLabel(tr("change density"),help3);
+	QLabel *l8  = new QLabel(tr("x phase shift"),help3);
+	QLabel *l9  = new QLabel(tr("y phase shift"),help3);
+	QLabel *l10 = new QLabel(tr("z phase shift"),help3);
+	QLabel *l11 = new QLabel(tr("toggle information"),help3);
+	Q3VBox *help4 = new Q3VBox(help2);
+	QLabel *c1  = new QLabel(tr("cursor keys, mouse dragging"),help4);
+	QLabel *c2  = new QLabel(tr("page up / page down"),help4);
+	QLabel *c3  = new QLabel(tr("r / t"),help4);
+	QLabel *c4  = new QLabel(tr("g / h"),help4);
+	QLabel *c5  = new QLabel(tr("b / n"),help4);
+	QLabel *c6  = new QLabel(tr("+ / -"),help4);
+	QLabel *c7  = new QLabel(tr("Ins / Del"),help4);
+	QLabel *c8  = new QLabel(tr("y / x"),help4);
+	QLabel *c9  = new QLabel(tr("a / s"),help4);
+	QLabel *c10 = new QLabel(tr("q / w"),help4);
+	QLabel *c11 = new QLabel(tr("i"),help4);
+
+	if (!(l1  && l2  && l3  && l4  && l5  && l6  && l7  && l8  && l9  && l10 && l11
+	   && c1  && c2  && c3  && c4  && c5  && c6  && c7  && c8  && c9  && c10 && c11))
+		return;
+
 
 	help->setSpacing(20);
 	help2->setSpacing(20);
@@ -294,7 +303,7 @@ void QLiss3D::paintEvent(QPaintEvent *){
 	     a.z += 440;
 
 	     e = xycoord(a,k);
-	     if(ls && 800 > e.x > 0 && 600 > e.y > 0 && 800 > eold.x > 0 && 600 > eold.y > 0)
+	     if(ls && 800 > e.x && e.x > 0 && 600 > e.y && e.y > 0 && 800 > eold.x && eold.x  > 0 && 600 > eold.y  && eold.y > 0)
 	     	p.drawLine(int(e.x), int(e.y), int(eold.x), int(eold.y));
 	     else
 	     	p.drawPoint(int(e.x), int(e.y));
@@ -339,10 +348,10 @@ void QLiss3D::keyPressEvent(QKeyEvent * e){
 		case Qt::Key_Down:
 			setYAngle(yang-1);
 			break;
-		case Qt::Key_Prior:
+		case Qt::Key_PageUp:
 			setXAngle(0);
 			break;
-		case Qt::Key_Next:
+		case Qt::Key_PageDown:
 			setYAngle(0);
 			break;
 		case Qt::Key_R:
@@ -457,15 +466,15 @@ void QLiss3D::playWav(){
 }
 
 // constructor for the menubar
-QLiss3DObject::QLiss3DObject(QWidget *parent, const char *name) : QVBox(parent, name){
-	QHBox * menu;
-	menu = new QHBox(this, "Liss-Menu");
+QLiss3DObject::QLiss3DObject(QWidget *parent, const char *name) : Q3VBox(parent, name){
+	Q3HBox * menu;
+	menu = new Q3HBox(this, "Liss-Menu");
 	menu->setSpacing(10);
 	
-	QVBox      * abox;
-	abox   = new QVBox(menu, "Angle-Box");
-	QHBox      * albox;
-	albox  = new QHBox(abox, "Angle-Label-Box");
+	Q3VBox      * abox;
+	abox   = new Q3VBox(menu, "Angle-Box");
+	Q3HBox      * albox;
+	albox  = new Q3HBox(abox, "Angle-Label-Box");
 	QLabel     * alabel;
 	alabel = new QLabel(tr("Angle:"),albox,"Angle-Label");
 	QLCDNumber * xalcd;
@@ -481,10 +490,10 @@ QLiss3DObject::QLiss3DObject(QWidget *parent, const char *name) : QVBox(parent,
 	connect(yangle,SIGNAL(valueChanged(int)),yalcd,SLOT(display(int)));
 
 	
-	QVBox      * pbox;
-	pbox   = new QVBox(menu, "pixel-Box");
-	QHBox      * plbox;
-	plbox  = new QHBox(pbox, "pixel-Label-Box");
+	Q3VBox      * pbox;
+	pbox   = new Q3VBox(menu, "pixel-Box");
+	Q3HBox      * plbox;
+	plbox  = new Q3HBox(pbox, "pixel-Label-Box");
 	QLabel     * plabel;
 	plabel = new QLabel(tr("Points:"),plbox,"pixel-Label");
 	QSpinBox   * pixel;
@@ -502,10 +511,10 @@ QLiss3DObject::QLiss3DObject(QWidget *parent, const char *name) : QVBox(parent,
 	kss  = new QSpinBox(50, 2000, 10, kbox, "k-Slider");
 	kss->setValue(800);*/
 
-	QVBox *xfbox, *yfbox, *zfbox;
-	xfbox = new QVBox(menu, "x-Freq-VBox");
-	yfbox = new QVBox(menu, "y-Freq-VBox");
-	zfbox = new QVBox(menu, "z-Freq-VBox");
+	Q3VBox *xfbox, *yfbox, *zfbox;
+	xfbox = new Q3VBox(menu, "x-Freq-VBox");
+	yfbox = new Q3VBox(menu, "y-Freq-VBox");
+	zfbox = new Q3VBox(menu, "z-Freq-VBox");
 
 	QLabel *xfl, *yfl, *zfl;
 	xfl = new QLabel(tr("x-frequency:"),xfbox, "XFLabel");
