@@ -6,7 +6,11 @@
 // (c) 2003 by Daniel Gruen <daniel_gruen@web.de>
 
 #include <qwidget.h>
-#include <qvbox.h>
+#include <q3vbox.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QKeyEvent>
+#include <QPaintEvent>
 
 const double pi = 3.14159265359;
 const double pi180 = pi/180.0;
@@ -37,7 +41,7 @@ class QLiss3D : public QWidget {
 	bool  ls,is;
 	int   msx,msy;
 	bool  really_repaint;
-	QVBox *help;
+	Q3VBox *help;
 
     public slots:
 	void  setXAngle(int degrees);
@@ -83,7 +87,7 @@ class QLiss3D : public QWidget {
 	void mouseMoveEvent(QMouseEvent * e);
 };
 
-class QLiss3DObject : public QVBox {
+class QLiss3DObject : public Q3VBox {
     Q_OBJECT
     public:
 	QLiss3DObject(QWidget *parent=0, const char *name = 0);
